==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/form-view/DataLayoutBuilderInstanceProvider.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/form-view/DataLayoutBuilderInstanceProvider.es", ['module', 'exports', 'require', 'data-engine-taglib', 'frontend-js-react-web$react', '../../utils/generateDataDefinitionFieldName.es', './DataLayoutBuilderInstanceContext.es', './FormViewContext.es', './useDeleteDefinitionField.es', './useDeleteDefinitionFieldModal.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dataEngineTaglib = require("data-engine-taglib");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _generateDataDefinitionFieldName = _interopRequireDefault(require("../../utils/generateDataDefinitionFieldName.es"));

  var _DataLayoutBuilderInstanceContext = _interopRequireDefault(require("./DataLayoutBuilderInstanceContext.es"));

  var _FormViewContext = _interopRequireDefault(require("./FormViewContext.es"));

  var _useDeleteDefinitionField = _interopRequireDefault(require("./useDeleteDefinitionField.es"));

  var _useDeleteDefinitionFieldModal = _interopRequireDefault(require("./useDeleteDefinitionFieldModal.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var children = _ref.children,
        dataLayoutBuilder = _ref.dataLayoutBuilder;

    var _useContext = (0, _react.useContext)(_FormViewContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        _useContext2$ = _useContext2[0],
        dataDefinition = _useContext2$.dataDefinition,
        dataLayout = _useContext2$.dataLayout,
        dispatch = _useContext2[1];

    var deleteDefinitionField = (0, _useDeleteDefinitionField["default"])({
      dataLayoutBuilder: dataLayoutBuilder
    });
    var onDeleteDefinitionField = (0, _useDeleteDefinitionFieldModal["default"])(function (fieldName) {
      deleteDefinitionField(fieldName);
    });
    (0, _react.useEffect)(function () {
      var provider = dataLayoutBuilder.getLayoutProvider();
      provider.props.fieldActions = [{
        action: function action(fieldName) {
          return dataLayoutBuilder.dispatch('fieldDuplicated', {
            fieldName: fieldName
          });
        },
        label: Liferay.Language.get('duplicate')
      }, {
        action: function action(fieldName) {
          dispatch({
            payload: {
              fieldName: fieldName
            },
            type: _dataEngineTaglib.DataLayoutBuilderActions.DELETE_DATA_LAYOUT_FIELD
          });
          dataLayoutBuilder.dispatch('fieldDeleted', {
            fieldName: fieldName
          });
        },
        label: Liferay.Language.get('remove'),
        separator: true
      }, {
        action: function action(fieldName) {
          onDeleteDefinitionField(fieldName);
        },
        label: Liferay.Language.get('delete-from-object'),
        style: 'danger'
      }];

      provider.props.shouldAutoGenerateName = function () {
        return false;
      };
    }, [dataLayout, dataLayoutBuilder, dispatch, onDeleteDefinitionField]);
    (0, _react.useEffect)(function () {
      var provider = dataLayoutBuilder.getLayoutProvider();

      provider.props.fieldNameGenerator = function (desiredFieldName) {
        return (0, _generateDataDefinitionFieldName["default"])(dataDefinition, desiredFieldName);
      };
    }, [dataDefinition, dataLayoutBuilder]);
    return _react["default"].createElement(_DataLayoutBuilderInstanceContext["default"].Provider, {
      value: [dataLayoutBuilder, dataLayoutBuilder.dispatch]
    }, children);
  };

  exports["default"] = _default;
  //# sourceMappingURL=DataLayoutBuilderInstanceProvider.es.js.map
});
//# sourceMappingURL=DataLayoutBuilderInstanceProvider.es.js.map

==> com.liferay.app.builder.web-1.0.31.jar: META-INF/resources/js/pages/form-view/DataLayoutBuilderInstanceProvider.es.js <==
Liferay.Loader.define("app-builder-web@1.0.31/js/pages/form-view/DataLayoutBuilderInstanceProvider.es", ['module', 'exports', 'require', 'data-engine-taglib', 'frontend-js-react-web$react', '../../utils/generateDataDefinitionFieldName.es', './DataLayoutBuilderInstanceContext.es', './FormViewContext.es', './useDeleteDefinitionField.es', './useDeleteDefinitionFieldModal.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dataEngineTaglib = require("data-engine-taglib");

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _generateDataDefinitionFieldName = _interopRequireDefault(require("../../utils/generateDataDefinitionFieldName.es"));

  var _DataLayoutBuilderInstanceContext = _interopRequireDefault(require("./DataLayoutBuilderInstanceContext.es"));

  var _FormViewContext = _interopRequireDefault(require("./FormViewContext.es"));

  var _useDeleteDefinitionField = _interopRequireDefault(require("./useDeleteDefinitionField.es"));

  var _useDeleteDefinitionFieldModal = _interopRequireDefault(require("./useDeleteDefinitionFieldModal.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _toConsumableArray(arr) {
    return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
  }

  function _nonIterableSpread() {
    throw new TypeError("Invalid attempt to spread non-iterable instance");
  }

  function _iterableToArray(iter) {
    if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
  }

  function _arrayWithoutHoles(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }return arr2;
    }
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var children = _ref.children,
        dataLayoutBuilder = _ref.dataLayoutBuilder;

    var _useContext = (0, _react.useContext)(_FormViewContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        _useContext2$ = _useContext2[0],
        dataDefinition = _useContext2$.dataDefinition,
        editingLanguageId = _useContext2$.editingLanguageId,
        focusedField = _useContext2$.focusedField,
        dispatch = _useContext2[1];

    var deleteDefinitionField = (0, _useDeleteDefinitionField["default"])({
      dataLayoutBuilder: dataLayoutBuilder
    });
    var onDeleteDefinitionField = (0, _useDeleteDefinitionFieldModal["default"])(function (fieldName) {
      deleteDefinitionField(fieldName);
    });
    (0, _react.useEffect)(function () {
      var provider = dataLayoutBuilder.getLayoutProvider();
      provider.props = _objectSpread({}, provider.props, {
        availableLanguageIds: _toConsumableArray(new Set([].concat(_toConsumableArray(provider.props.availableLanguageIds), [editingLanguageId]))),
        editingLanguageId: editingLanguageId
      });

      if (Object.keys(focusedField).length) {
        provider.getEvents().fieldClicked(focusedField);
      } // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [dataLayoutBuilder, dispatch, editingLanguageId]);
    (0, _react.useEffect)(function () {
      var provider = dataLayoutBuilder.getLayoutProvider();
      provider.props.fieldActions = [{
        action: function action(event) {
          return dataLayoutBuilder.dispatch('fieldDuplicated', event);
        },
        label: Liferay.Language.get('duplicate')
      }, {
        action: function action(event) {
          dispatch({
            payload: {
              fieldName: event.fieldName
            },
            type: _dataEngineTaglib.DataLayoutBuilderActions.DELETE_DATA_LAYOUT_FIELD
          });
          dataLayoutBuilder.dispatch('fieldDeleted', event);
        },
        label: Liferay.Language.get('remove'),
        separator: true
      }, {
        action: function action(_ref2) {
          var fieldName = _ref2.fieldName;
          onDeleteDefinitionField(fieldName);
        },
        label: Liferay.Language.get('delete-from-object'),
        style: 'danger'
      }];

      provider.props.shouldAutoGenerateName = function () {
        return false;
      };
    }, [dataLayoutBuilder, dispatch, onDeleteDefinitionField]);
    (0, _react.useEffect)(function () {
      var provider = dataLayoutBuilder.getLayoutProvider();

      provider.props.fieldNameGenerator = function (desiredFieldName, currentFieldName) {
        return (0, _generateDataDefinitionFieldName["default"])(dataDefinition, desiredFieldName, currentFieldName);
      };
    }, [dataDefinition, dataLayoutBuilder]);
    return _react["default"].createElement(_DataLayoutBuilderInstanceContext["default"].Provider, {
      value: [dataLayoutBuilder, dataLayoutBuilder.dispatch]
    }, children);
  };

  exports["default"] = _default;
  //# sourceMappingURL=DataLayoutBuilderInstanceProvider.es.js.map
});
//# sourceMappingURL=DataLayoutBuilderInstanceProvider.es.js.map
